@@ -11,6 +11,12 @@ from .driver import run
 
 
 def main(argv=sys.argv):
+    """
+    Entry point for spotilyzer. All exceptions are caught displayed and
+    returned as a failing exit code.
+    :param argv: command line arguments
+    :return: exit code
+    """
     try:
         args = parse_cmdline(argv)
         run(args)
